@@ -1,6 +1,8 @@
 import os
+import shutil
 
 import pandas as pd
+import xarray as xr
 import sqlalchemy as sa
 from sqlalchemy.orm import object_session
 from sqlalchemy.dialects.postgresql import ARRAY
@@ -161,6 +163,11 @@ def import_to_local_csv_file(entry, datasource, data, **kwargs):
     # get the path
     if datasource.path is None:
         path = os.path.join(os.path.expanduser('~'))
+    else:
+        path = datasource.path
+    
+    # always use absolute paths
+    path = os.path.abspath(path)
 
     # check for filename
     if not path.endswith('.csv'):
@@ -188,12 +195,86 @@ def import_to_local_csv_file(entry, datasource, data, **kwargs):
         if os.path.exists(path):
             raise ValueError('%s already exists.' % path)
         else:
-            data.to_csv(path, index=None)
+            imp.to_csv(path, index=None)
 
     else:
         raise ValueError("if_exists has to be one of ['fail', 'append', 'replace']")
 
 
+def import_to_local_netcdf_file(entry, datasource, data, **kwargs):
+    """
+    .. versionadded:: 0.5.3
+    
+    Import to netCDF
+    Saves data to a local netCDF file.
+    Any existing file will be overwritten.
+    The default location can be overwritten using the path keyword.
+
+    Parameters
+        ----------
+    entry : metacatlog.models.Entry
+        Metacatalog entry for which the data is to be uploaded.
+    datasource : metacatalog.models.Datasource
+        Datasource of the given entry.
+    data : Union[str, xarray.Dataset]
+        Can be either the path to your locally saved netCDF file
+        or a xarray.Dataset
+
+    """
+    assert Entry.is_valid(entry)
+
+    # get the path
+    if datasource.path is None:
+        path = os.path.join(os.path.expanduser('~'))
+    else:
+        path = datasource.path
+
+    # always use absolute paths
+    path = os.path.abspath(path)
+
+    # check for filename
+    if not path.endswith('.nc'):
+        path = os.path.join(path, 'entry_%d.nc' % entry.id)
+        datasource.path = path
+
+        # save new path
+        __update_datasource(datasource)
+
+    if_exists = kwargs.get('if_exists', 'replace')
+
+    # check type of data
+    if type(data) not in [str, xr.Dataset]:
+        raise TypeError("The type of data has to be str (path) or xr.Dataset")
+
+    # save the data
+    if if_exists == 'replace':
+        if type(data) == xr.Dataset:
+            data.to_netcdf(path, mode='w')
+        else:
+            shutil.copy(data, path)
+
+    elif if_exists == 'append':
+        if type(data) == xr.Dataset:
+            data.to_netcdf(path, mode='a')
+        else:
+            # open the netCDF file in path and in data and combine
+            ds_combined = xr.open_mfdataset([path, data], combine='by_coords', concat_dim='time')
+
+            # save combined netCDF to path, overwrite existing/old netCDF
+            ds_combined.to_netcdf(path, mode='w')
+
+    elif if_exists == 'fail':
+        if os.path.exists(path):
+            raise ValueError('%s already exists.' % path)
+        else:
+            if type(data) == xr.Dataset:
+                data.to_netcdf(path, mode='w')
+            else:
+                shutil.copy(data, path)
+    else:
+        raise ValueError("if_exists has to be one of ['fail', 'append', 'replace']")
+
+
 def __update_datasource(datasource):
     try:
         session = object_session(datasource)
